@@ -8,7 +8,6 @@
 # copied, modified, or distributed except according to those terms.
 
 import json
-import os
 
 import click
 import usb.core
@@ -19,20 +18,9 @@ from solo.cli.key import key
 from solo.cli.monitor import monitor
 from solo.cli.program import program
 
-from . import _patches  # noqa  (since otherwise "unused")
+from ._checks import init_checks
 
-if (os.name == "posix") and os.environ.get("ALLOW_ROOT") is None:
-    if os.geteuid() == 0:
-        print("THIS COMMAND SHOULD NOT BE RUN AS ROOT!")
-        print()
-        print(
-            "Please install udev rules and run `solo` as regular user (without sudo)."
-        )
-        print(
-            "We suggest using: https://github.com/solokeys/solo/blob/master/udev/70-solokeys-access.rules"
-        )
-        print()
-        print("For more information, see: https://docs.solokeys.io/solo/udev/")
+init_checks()
 
 
 @click.group()
@@ -148,10 +136,13 @@ def ls(all):
     print(":: Solos")
     for c in solos:
         descriptor = c.dev.descriptor
-        if "serial_number" in descriptor:
-            print(f"{descriptor['serial_number']}: {descriptor['product_string']}")
+        if hasattr(descriptor, "serial_number") and descriptor.serial_number:
+            print(f"{descriptor.serial_number}: {descriptor.product_string}")
         else:
-            print(f"{descriptor['path']}: {descriptor['product_string']}")
+            if c.is_solo_bootloader():
+                print(f"{descriptor.path}: Solo Bootloader device")
+            else:
+                print(f"{descriptor.path}: FIDO2 device")
 
     if all:
         print(":: Potential Solos in DFU mode")
